==> hibernate-core-6.0.0.Final-sources.jar: hbm/org/hibernate/boot/jaxb/hbm/spi/JaxbHbmSubclassEntityBaseDefinition.java <==

package org.hibernate.boot.jaxb.hbm.spi;

import java.io.Serializable;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlSeeAlso;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SubclassEntityBaseDefinition complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SubclassEntityBaseDefinition"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.hibernate.org/xsd/orm/hbm}EntityBaseDefinition"&gt;
 *       &lt;attribute name="extends" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SubclassEntityBaseDefinition", namespace = "http://www.hibernate.org/xsd/orm/hbm")
@XmlSeeAlso({
    JaxbHbmDiscriminatorSubclassEntityType.class,
    JaxbHbmJoinedSubclassEntityType.class,
    JaxbHbmUnionSubclassEntityType.class
})
public abstract class JaxbHbmSubclassEntityBaseDefinition
    extends JaxbHbmEntityBaseDefinition
    implements Serializable
{

    @XmlAttribute(name = "extends")
    protected String _extends;

    /**
     * Gets the value of the extends property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getExtends() {
        return _extends;
    }

    /**
     * Sets the value of the extends property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setExtends(String value) {
        this._extends = value;
    }

}

==> hibernate-core-6.2.13.Final-sources.jar: hbm/org/hibernate/boot/jaxb/hbm/spi/JaxbHbmSubclassEntityBaseDefinition.java <==

package org.hibernate.boot.jaxb.hbm.spi;

import java.io.Serializable;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlSeeAlso;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SubclassEntityBaseDefinition complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="SubclassEntityBaseDefinition">
 *   <complexContent>
 *     <extension base="{http://www.hibernate.org/xsd/orm/hbm}EntityBaseDefinition">
 *       <attribute name="extends" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SubclassEntityBaseDefinition", namespace = "http://www.hibernate.org/xsd/orm/hbm")
@XmlSeeAlso({
    JaxbHbmDiscriminatorSubclassEntityType.class,
    JaxbHbmJoinedSubclassEntityType.class,
    JaxbHbmUnionSubclassEntityType.class
})
public abstract class JaxbHbmSubclassEntityBaseDefinition
    extends JaxbHbmEntityBaseDefinition
    implements Serializable
{

    @XmlAttribute(name = "extends")
    protected String _extends;

    /**
     * Gets the value of the extends property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getExtends() {
        return _extends;
    }

    /**
     * Sets the value of the extends property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setExtends(String value) {
        this._extends = value;
    }

}
